@@ -4,18 +4,19 @@ Main interface for rds-data service type definitions.
 Usage::
 
     ```python
-    from mypy_boto3_rds_data.type_defs import ArrayValueTypeDef
+    from mypy_boto3_rds_data.type_defs import ColumnMetadataTypeDef
 
-    data: ArrayValueTypeDef = {...}
+    data: ColumnMetadataTypeDef = {...}
     ```
 """
 import sys
-from typing import List
+from typing import Any, Dict, List
 
 if sys.version_info >= (3, 8):
     from typing import Literal
 else:
     from typing_extensions import Literal
+
 if sys.version_info >= (3, 8):
     from typing import TypedDict
 else:
@@ -23,7 +24,6 @@ else:
 
 
 __all__ = (
-    "ArrayValueTypeDef",
     "ColumnMetadataTypeDef",
     "FieldTypeDef",
     "RecordTypeDef",
@@ -32,10 +32,11 @@ __all__ = (
     "SqlStatementResultTypeDef",
     "StructValueTypeDef",
     "UpdateResultTypeDef",
-    "ValueTypeDef",
     "BatchExecuteStatementResponseTypeDef",
     "BeginTransactionResponseTypeDef",
     "CommitTransactionResponseTypeDef",
+    "ArrayValueTypeDef",
+    "ValueTypeDef",
     "ExecuteSqlResponseTypeDef",
     "ExecuteStatementResponseTypeDef",
     "ResultSetOptionsTypeDef",
@@ -43,18 +44,6 @@ __all__ = (
     "SqlParameterTypeDef",
 )
 
-ArrayValueTypeDef = TypedDict(
-    "ArrayValueTypeDef",
-    {
-        "arrayValues": List["ArrayValueTypeDef"],
-        "booleanValues": List[bool],
-        "doubleValues": List[float],
-        "longValues": List[int],
-        "stringValues": List[str],
-    },
-    total=False,
-)
-
 ColumnMetadataTypeDef = TypedDict(
     "ColumnMetadataTypeDef",
     {
@@ -79,7 +68,7 @@ ColumnMetadataTypeDef = TypedDict(
 FieldTypeDef = TypedDict(
     "FieldTypeDef",
     {
-        "arrayValue": "ArrayValueTypeDef",
+        "arrayValue": Dict[str, Any],
         "blobValue": bytes,
         "booleanValue": bool,
         "doubleValue": float,
@@ -90,7 +79,7 @@ FieldTypeDef = TypedDict(
     total=False,
 )
 
-RecordTypeDef = TypedDict("RecordTypeDef", {"values": List["ValueTypeDef"]}, total=False)
+RecordTypeDef = TypedDict("RecordTypeDef", {"values": List[Dict[str, Any]]}, total=False)
 
 ResultFrameTypeDef = TypedDict(
     "ResultFrameTypeDef",
@@ -111,30 +100,13 @@ SqlStatementResultTypeDef = TypedDict(
 )
 
 StructValueTypeDef = TypedDict(
-    "StructValueTypeDef", {"attributes": List["ValueTypeDef"]}, total=False
+    "StructValueTypeDef", {"attributes": List[Dict[str, Any]]}, total=False
 )
 
 UpdateResultTypeDef = TypedDict(
     "UpdateResultTypeDef", {"generatedFields": List["FieldTypeDef"]}, total=False
 )
 
-ValueTypeDef = TypedDict(
-    "ValueTypeDef",
-    {
-        "arrayValues": List["ValueTypeDef"],
-        "bigIntValue": int,
-        "bitValue": bool,
-        "blobValue": bytes,
-        "doubleValue": float,
-        "intValue": int,
-        "isNull": bool,
-        "realValue": float,
-        "stringValue": str,
-        "structValue": "StructValueTypeDef",
-    },
-    total=False,
-)
-
 BatchExecuteStatementResponseTypeDef = TypedDict(
     "BatchExecuteStatementResponseTypeDef",
     {"updateResults": List["UpdateResultTypeDef"]},
@@ -149,6 +121,35 @@ CommitTransactionResponseTypeDef = TypedDict(
     "CommitTransactionResponseTypeDef", {"transactionStatus": str}, total=False
 )
 
+ArrayValueTypeDef = TypedDict(
+    "ArrayValueTypeDef",
+    {
+        "arrayValues": List[Dict[str, Any]],
+        "booleanValues": List[bool],
+        "doubleValues": List[float],
+        "longValues": List[int],
+        "stringValues": List[str],
+    },
+    total=False,
+)
+
+ValueTypeDef = TypedDict(
+    "ValueTypeDef",
+    {
+        "arrayValues": List[Dict[str, Any]],
+        "bigIntValue": int,
+        "bitValue": bool,
+        "blobValue": bytes,
+        "doubleValue": float,
+        "intValue": int,
+        "isNull": bool,
+        "realValue": float,
+        "stringValue": str,
+        "structValue": "StructValueTypeDef",
+    },
+    total=False,
+)
+
 ExecuteSqlResponseTypeDef = TypedDict(
     "ExecuteSqlResponseTypeDef",
     {"sqlStatementResults": List["SqlStatementResultTypeDef"]},
